@@ -1,6 +1,6 @@
 #!/usr/bin/perl
 #
-# $Id: Logwatch.pm,v 1.13 2005/09/12 22:13:10 bjorn Exp $
+# $Id$
 
 package Logwatch;
 
@@ -85,7 +85,7 @@ our @ISA = qw{Exporter};
 our @EXPORT;
 our @EXPORT_OK;
 our %EXPORT_TAGS = (sort => [qw(CountOrder TotalCountOrder SortIP)],
-                    ip   => [qw(LookupIP SortIP)],
+                    ip   => [qw(DoLookup LookupIP SortIP)],
                     dates   => [qw(RangeHelpDM GetPeriod TimeBuild TimeFilter)],
                     );
 
@@ -200,7 +200,7 @@ sub TotalCountOrder(\%;&) {
             }
         }
         my $count = $BB <=> $AA;
-        
+
         return $count if $count;
         if (ref $coderef) {
             $a = $A;
@@ -261,10 +261,15 @@ sub SortIP {
 
 =pod
 
+=item I<DoLookup($DoLookup)>
+
+Sets whether C<LookupIP> does hostname lookups (or not).
+Defaults to true.
+
 =item I<LookupIP($dottedQuadIPaddress)>
 
 This function performs a hostname lookup on a passed in IP address. It
-returns the hostname (with the IP in parentheses) on success and the IP
+returns the IP (with the hostname in parentheses) on success and the IP
 address on failure. Results are cached, so that many calls with the same
 argument don't tax the resolver resources.
 
@@ -273,40 +278,23 @@ variable in the caller's namespace to determine if lookups will be made.
 
 =cut
 
+# Default to false
+my $DoLookup = 0;
+
+sub DoLookup {
+    $DoLookup = shift;
+    return;
+}
+
 # Might as well cache it for the duration of the run
 my %LookupCache = ();
 
 sub LookupIP {
    my $Addr = $_[0];
 
-   # OOPS! The 4.3.2 scripts have a $DoLookup variable. Time for some
-   # backwards compatible hand-waving.
-
-   # for 99% of the uses of this function, assuming package 'main' would
-   # be sufficient, but a good perl hacker designs so that the other 1%
-   # isn't in for a nasty suprise.
-   my $pkg = (caller)[0];
-
    if ($ENV{'LOGWATCH_NUMERIC'} == 1 )
       { return $Addr; }
 
-   # Default to true
-   my $DoLookup = 1;
-   {
-       # An eval() here would be shorter (and probably clearer to more
-       # people), but QUITE a bit slower. This function should be
-       # designed to be called a lot, so efficiency is important.
-       local *symTable = $main::{"$pkg\::"};
-
-       # here comes the "black magic," (this "no" is bound to the
-       # enclosing block)
-       no strict 'vars';
-       if (exists $symTable{'DoLookup'} && defined $symTable{'DoLookup'}) {
-           *symTable = $symTable{'DoLookup'};
-           $DoLookup = $symTable;
-       }
-   }
-
    # "Socket" is used solely to get the AF_INET() and AF_INET6()
    # constants, usually 2 and 10, respectively.  Using Socket is
    # preferred because of portability, and should be in the standard
@@ -347,7 +335,7 @@ sub LookupIP {
 This function merely prints out some information about --range to STDERR.
 
 =cut
-    
+
 sub RangeHelpDM {
    eval "use Date::Manip"; my $hasDM = $@ ? 0 : 1;
 
@@ -356,8 +344,9 @@ sub RangeHelpDM {
        print STDERR "of the valid --range parameters.\n";
    } else {
        print STDERR "\nThis system does not have Date::Manip module loaded, and therefore\n";
-       print STDERR "the only valid --range parameters are 'yesterday', 'today', or 'all'.\n";
+       print STDERR "the only valid --range parameters are \"yesterday\", \"today\", or \"all\".\n";
        print STDERR "The Date::Manip module can be installed by using either of:\n";
+       print STDERR "   apt-get install libdate-manip-perl (recommended on Debian)'\n";
        print STDERR "   cpan -i 'Date::Manip'\n";
        print STDERR "   perl -MCPAN -e 'install Date::Manip'\n";
        print STDERR "\nFollowing is a description of the full capabilities available if\n";
@@ -369,9 +358,9 @@ sub RangeHelpDM {
 The format of the range option is:
     --range \"date_range [period]\"
 
-Parameter date_range (and optional period) must be enclosed in quotes if it is
-more than one word.  The default for date_range is \"yesterday\". Valid
-instances of date_range have one of the following formats:
+Parameter date_range (and optional period) must be enclosed in double quotes
+if it is more than one word.  The default for date_range is \"yesterday\".
+Valid instances of date_range have one of the following formats:
 
    yesterday
    today
@@ -396,19 +385,19 @@ Examples:
 
    --range today
    --range yesterday
-   --range '4 hours ago for that hour'
-   --range '-3 days'
-   --range 'since 2 hours ago for those hours'
-   --range 'between -10 and -2 days'
-   --range 'Apr 15, 2005'
-   --range 'first Monday in May'
-   --range 'between 4/23/2005 and 4/30/2005'
-   --range '2005/05/03 10:24:17 for that second'
+   --range \"4 hours ago for that hour\"
+   --range \"-3 days\"
+   --range \"since 2 hours ago for those hours\"
+   --range \"between -10 days and -2 days\"
+   --range \"Apr 15, 2005\"
+   --range \"first Monday in May\"
+   --range \"between 4/23/2005 and 4/30/2005\"
+   --range \"2005/05/03 10:24:17 for that second\"
 
 (The last entry might be used by someone debugging a log or filter.)
 
 A caution about efficiency: a range of \"yesterday for those hours\"
-will search for log entries for the last 24 hours, and is innefficient
+will search for log entries for the last 24 hours, and is inefficient
 because it searches for individual matches for each hour.  A range of
 \"yesterday\" will search for log entries for the previous day, and
 it searches for a single date match.
@@ -426,7 +415,7 @@ This function returns the period, which is the part after the "for (those|that|t
 in a range
 
 =cut
-    
+
 sub GetPeriod {
 
    my $range = lc $ENV{"LOGWATCH_DATE_RANGE"} || "yesterday";
@@ -454,6 +443,13 @@ sub TimeBuild {
    my $time = time;
    eval "use Date::Manip"; my $hasDM = $@ ? 0 : 1;
 
+   if ($hasDM) {
+      eval 'Date_TimeZone();';
+      if ($@) {
+         die "ERROR: Date::Manip unable to determine TimeZone.\n\nExecute the following command in a shell prompt:\n\tperldoc Date::Manip\nThe section titled TIMEZONES describes valid TimeZones\nand where they can be defined.\n";
+      }
+   }
+
    my $range = lc $ENV{"LOGWATCH_DATE_RANGE"} || "yesterday";
    my $period = GetPeriod;
    $range =~ s/for\s+(?:those|that|this)\s+((year|month|day|hour|minute|second)s?)\s*$//;
@@ -526,13 +522,11 @@ sub TimeBuild {
 This function returns a regexp to filter by date/time
 
 =cut
-    
+
 
 sub TimeFilter {
    my ($format) = $_[0];
 
-   eval "use Date::Manip"; my $hasDM = $@ ? 0 : 1;
-    
    my $SearchDate;
 
    my $range = lc $ENV{"LOGWATCH_DATE_RANGE"} || "yesterday";
@@ -557,7 +551,7 @@ sub TimeFilter {
            $format =~ s/%a/.../;
            $format =~ s/%d/../;
            $format =~ s/%e/../;
-           if ($period eq 'month') {last;}      
+           if ($period eq 'month') {last;}
            $format =~ s/%b/.../;
            $format =~ s/%m/../;
            if ($period eq 'year') {last;}
@@ -566,7 +560,7 @@ sub TimeFilter {
    }
 
    $SearchDate .= "(";
-    
+
    for my $time (@time_t) {
         if ($time) {
            $SearchDate .= strftime($format, localtime($time)) . "|";
@@ -612,7 +606,7 @@ Imports C<CountOrder>, C<TotalCountOrder and C<SortIP>
 
 =item I<:ip>
 
-Imports C<SortIP> and C<LookupIP>
+Imports C<DoLookup>, C<LookupIP>, and C<SortIP>
 
 =item I<:dates>
 
